summaryrefslogtreecommitdiff
path: root/keyboards/skyloong/gk61/v1/v1.c
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/skyloong/gk61/v1/v1.c')
-rw-r--r--keyboards/skyloong/gk61/v1/v1.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/keyboards/skyloong/gk61/v1/v1.c b/keyboards/skyloong/gk61/v1/v1.c
index 5fed5701b2..cb3772f6b4 100644
--- a/keyboards/skyloong/gk61/v1/v1.c
+++ b/keyboards/skyloong/gk61/v1/v1.c
@@ -17,8 +17,8 @@
#ifdef RGB_MATRIX_ENABLE
-const ckled2001_led PROGMEM g_ckled2001_leds[RGB_MATRIX_LED_COUNT] = {
-/* Refer to CKLED2001 manual for these locations
+const snled27351_led_t PROGMEM g_snled27351_leds[RGB_MATRIX_LED_COUNT] = {
+/* Refer to SNLED27351 manual for these locations
* driver
* | R location
* | | G location